| attentionrct | R Documentation |
This dataset provides individual-level information from a randomized experiment studying the effect of poverty on cognitive performance. Low-income participants were randomly assigned to take a cognitive test either before or after payday. The outcome measures the number of correct answers on a test designed to assess cognitive ability. The data includes pre-treatment characteristics such as age, income, education, and other demographic variables.
attentionrct
A data frame containing outcomes and pre-treatment characteristics for each participant.
Original data licensed under Creative Commons Attribution 4.0 (CC BY 4.0). This version has been lightly processed for demonstration purposes.
American Economic Association replication archive. (Carvalho et al., 2016, and Farbmacher et al., 2021)
Carvalho, Leandro S., Stephan Meier, and Stephanie W. Wang. "Poverty and economic decision-making: Evidence from changes in financial resources at payday." American Economic Review 106, no. 2 (2016): 260-84.
Farbmacher, Helmut, Heinrich Kögel, and Martin Spindler. "Heterogeneous effects of poverty on attention." Labour Economics 71 (2021): 102028.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.