grf package options can be set using R's options command. The current available options are:

  • `grf.verbose`: controls whether information is printed during training. The default value is `FALSE`.

  • `grf.legacy.seed`: controls whether grf's random seed behavior depends on the number of CPU threads used to train the forest. The default value is `FALSE`. Set to `TRUE` to recover results produced with grf versions prior to 2.4.0.

grf_options()

Value

Prints the current grf package options.

Examples

# \donttest{ # Enable progress output during training. options(grf.verbose = TRUE) n <- 1500 p <- 10 X <- matrix(rnorm(n * p), n, p) Y <- X[, 1] * rnorm(n) r.forest <- regression_forest(X, Y)
#> training [regression]: 0%| | 0/2000 [00:00:00<?, ?it/s] training [regression]: 0%| | 0/2000 [00:00:00<?, ?it/s] training [regression]: 0%| | 0/2000 [00:00:00<?, ?it/s] training [regression]: 0%| | 0/2000 [00:00:00<?, ?it/s] training [regression]: 7%| | 146/2000 [00:00:00<00:00:01, 1392.45it/s] training [regression]: 15%| | 292/2000 [00:00:00<00:00:01, 1420.39it/s] training [regression]: 22%|██ | 438/2000 [00:00:00<00:00:01, 1429.96it/s] training [regression]: 29%|███ | 586/2000 [00:00:00<00:00:00, 1440.31it/s] training [regression]: 37%|████ | 732/2000 [00:00:00<00:00:00, 1442.30it/s] training [regression]: 44%|████ | 876/2000 [00:00:00<00:00:00, 1440.07it/s] training [regression]: 51%|█████ | 1020/2000 [00:00:00<00:00:00, 1438.66it/s] training [regression]: 58%|██████ | 1166/2000 [00:00:00<00:00:00, 1439.90it/s] training [regression]: 66%|███████ | 1314/2000 [00:00:00<00:00:00, 1443.80it/s] training [regression]: 73%|███████ | 1458/2000 [00:00:01<00:00:00, 1442.45it/s] training [regression]: 80%|████████ | 1602/2000 [00:00:01<00:00:00, 1441.45it/s] training [regression]: 87%|█████████ | 1748/2000 [00:00:01<00:00:00, 1442.05it/s] training [regression]: 95%|█████████ | 1892/2000 [00:00:01<00:00:00, 1441.14it/s] training [regression]: 100%|██████████| 2000/2000 [00:00:01<00:00:00, 1442.30it/s]
options(grf.verbose = FALSE) # Print current package options. grf_options()
#> grf.verbose grf.legacy.seed #> FALSE FALSE
# Use random seed behavior prior to version 2.4.0. options(grf.legacy.seed = TRUE) # Use random seed independent of num.threads (default as of version 2.4.0 and higher). options(grf.legacy.seed = FALSE) # }