grf_options: grf package options

View source: R/grf_options.R

grf_optionsR Documentation

grf package options

Description

grf package options can be set using R's options command. The current available options are:

  • 'grf.verbose': controls whether information is printed during training. The default value is 'FALSE'.

  • ‘grf.legacy.seed': controls whether grf’s random seed behavior depends on the number of CPU threads used to train the forest. The default value is 'FALSE'. Set to 'TRUE' to recover results produced with grf versions prior to 2.4.0.

Usage

grf_options()

Value

Prints the current grf package options.

Examples


# Enable progress output during training.
options(grf.verbose = TRUE)
n <- 1500
p <- 10
X <- matrix(rnorm(n * p), n, p)
Y <- X[, 1] * rnorm(n)
r.forest <- regression_forest(X, Y)
options(grf.verbose = FALSE)

# Print current package options.
grf_options()

# Use random seed behavior prior to version 2.4.0.
options(grf.legacy.seed = TRUE)

# Use random seed independent of num.threads (default as of version 2.4.0 and higher).
options(grf.legacy.seed = FALSE)



grf documentation built on March 3, 2026, 9:07 a.m.